#
# Copyright Michael Orlitzky
#
# http://michael.orlitzky.com/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# http://www.fsf.org/licensing/licenses/gpl.html
#

require 'test/unit'
require 'src/websites/howcast'

# Unit tests for the Howcast class.
# This class is easy because get_video_url is
# just a string interpolation (we don't have to
# test that).

class HowcastTest < Test::Unit::TestCase

  def test_owns_howcast_urls    
    assert(Howcast.owns_url?('http://www.howcast.com/videos/6807-2twr'))
    assert(Howcast.owns_url?('www.howcast.com/videos/6807-2dgfdg'))
    assert(Howcast.owns_url?('http://howcast.com/videos/6807-cse'))
    assert(Howcast.owns_url?('howcast.com/videos/6807-asdgasd'))
  end

  
  def test_doesnt_own_redtube_urls
    assert(!Howcast.owns_url?('http://www.redtube.com/6807'))
    assert(!Howcast.owns_url?('www.redtube.com/6807'))
    assert(!Howcast.owns_url?('http://redtube.com/6807'))
    assert(!Howcast.owns_url?('redtube.com/6807'))
  end

  
  def test_doesnt_own_misc_urls
    assert(!Howcast.owns_url?('http://www.howcast.com/abc'))
  end

  
  def test_parse_file_path_from_xml
    hc = Howcast.new(nil)
    
    page_data = nil
    
    File.open('test/fixtures/howcast/81134.xml') do |f|
      page_data = f.read
    end
    
    test_result = hc.send('parse_file_path_from_xml', page_data)
    assert_equal('/system/videos/4/34/11/08/81134.flv', test_result)
  end
  
end
